<?php
namespace MikadoCore\CPT\Shortcodes\ClientsCarousel;

use MikadoCore\Lib;

class ClientsCarousel implements Lib\ShortcodeInterface {
	private $base;
	
	public function __construct() {
		$this->base = 'mkdf_clients_carousel';

		add_action('vc_before_init', array($this, 'vcMap'));
	}

	/**
	 * Returns base for shortcode
	 * @return string
	 */
	public function getBase() {
		return $this->base;
	}

	/**
	 * Maps shortcode to Visual Composer. Hooked on vc_before_init
	 */
	public function vcMap() {
		if(function_exists('vc_map')) {
			vc_map(
				array(
					'name'            => esc_html__( 'Mikado Clients Carousel', 'mkdf-core' ),
					'base'            => $this->getBase(),
					'category'        => esc_html__( 'by MIKADO', 'mkdf-core' ),
					'icon'            => 'icon-wpb-clients-carousel extended-custom-icon',
					'as_parent'       => array( 'only' => 'mkdf_clients_carousel_item' ),
					'content_element' => true,
					'js_view'         => 'VcColumnView',
					'params'          => array(
						array(
							'type' 			=> 'dropdown',
							'param_name' 	=> 'type',
							'heading'		=> esc_html__('Type', 'mkdf-core'),
							'value' 		=> array(
								esc_html__('Carousel', 'mkdf-core')	=> 'carousel',
								esc_html__('Grid', 'mkdf-core')		=> 'grid'
							)
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'number_of_visible_items',
							'heading'     => esc_html__( 'Number Of Visible Items', 'mkdf-core' ),
							'value'       => array(
								esc_html__( 'One', 'mkdf-core' )   => '1',
								esc_html__( 'Two', 'mkdf-core' )   => '2',
								esc_html__( 'Three', 'mkdf-core' ) => '3',
								esc_html__( 'Four', 'mkdf-core' )  => '4',
								esc_html__( 'Five', 'mkdf-core' )  => '5',
								esc_html__( 'Six', 'mkdf-core' )   => '6'
							),
							'save_always' => true,
							'dependency'  => array('element' => 'type', 'value' => 'carousel')
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'slider_loop',
							'heading'     => esc_html__( 'Enable Slider Loop', 'mkdf-core' ),
							'value'       => array_flip( mediclinic_mikado_get_yes_no_select_array( false, true ) ),
							'save_always' => true,
							'dependency'  => array('element' => 'type', 'value' => 'carousel')
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'slider_autoplay',
							'heading'     => esc_html__( 'Enable Slider Autoplay', 'mkdf-core' ),
							'value'       => array_flip( mediclinic_mikado_get_yes_no_select_array( false, true ) ),
							'save_always' => true,
							'dependency'  => array('element' => 'type', 'value' => 'carousel')
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'slider_speed',
							'heading'     => esc_html__( 'Slide Duration', 'mkdf-core' ),
							'description' => esc_html__( 'Default value is 5000 (ms)', 'mkdf-core' ),
							'dependency'  => array('element' => 'type', 'value' => 'carousel')
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'slider_speed_animation',
							'heading'     => esc_html__( 'Slide Animation Duration', 'mkdf-core' ),
							'description' => esc_html__( 'Speed of slide animation in milliseconds. Default value is 600.', 'mkdf-core' ),
							'dependency'  => array('element' => 'type', 'value' => 'carousel')
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'slider_navigation',
							'heading'     => esc_html__( 'Enable Slider Navigation Arrows', 'mkdf-core' ),
							'value'       => array_flip( mediclinic_mikado_get_yes_no_select_array( false ) ),
							'save_always' => true,
							'dependency'  => array('element' => 'type', 'value' => 'carousel')
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'slider_pagination',
							'heading'     => esc_html__( 'Enable Slider Pagination', 'mkdf-core' ),
							'value'       => array_flip( mediclinic_mikado_get_yes_no_select_array( false ) ),
							'save_always' => true,
							'dependency'  => array('element' => 'type', 'value' => 'carousel')
						),
						array(
								'type'        => 'dropdown',
								'admin_label' => true,
								'heading'     => esc_html__('Columns', 'mkdf-core'),
								'param_name'  => 'columns',
								'value'       => array(
										esc_html__('Two', 'mkdf-core')   => '2',
										esc_html__('Three', 'mkdf-core') => '3',
										esc_html__('Four', 'mkdf-core')  => '4',
										esc_html__('Five', 'mkdf-core')  => '5',
										esc_html__('Six', 'mkdf-core')   => '6'
								),
								'save_always' => true,
								'dependency'  => array('element' => 'type', 'value' => 'grid')
						),
						array(
								'type'        => 'checkbox',
								'heading'     => 'Disable Separators',
								'param_name'  => 'disable_separator',
								'value' => array(esc_html__('Disable separator between client items?', 'mkdf-core') => 'yes'),
								'admin_label' => true,
								'dependency'  => array('element' => 'type', 'value' => 'grid')
						)
					)
				)
			);
		}
	}

	/**
	 * Renders shortcodes HTML
	 *
	 * @param $atts array of shortcode params
	 * @param $content string shortcode content
	 * @return string
	 */
	public function render($atts, $content = null) {
		$args = array(
			'type'					  => 'carousel',
			'number_of_visible_items' => '4',
			'slider_loop'		      => 'yes',
			'slider_autoplay'		  => 'yes',
			'slider_speed'		      => '5000',
			'slider_speed_animation'  => '600',
			'slider_navigation'	      => 'no',
			'slider_pagination'	      => 'no',
			'columns' => '',
			'disable_separator' => ''
		);
		
		$params = shortcode_atts($args, $atts);
		
		$params['holder_classes'] = $this->getHolderClasses($params);
		$params['holder_inner_classes'] = $this->getHolderInnerClasses($params);
		$params['carousel_data']  = $this->getSliderData($params);
		$params['content'] = $content;
		
		$html = mkdf_core_get_shortcode_module_template_part('templates/clients-carousel', 'clients-carousel', '', $params);
		
		return $html;
	}
	
	/**
	 * Generates holder classes
	 *
	 * @param $params
	 *
	 * @return string
	 */
	private function getHolderClasses($params){
		$holderClasses = '';

		if( $params['type'] == 'grid'){

			$holderClasses   = array('mkdf-clients clearfix');
			$holderClasses[] = '';
			$columns = $params['columns'];


			switch ($columns) {
				case 2:
					$holderClasses[] = 'mkdf-clients-two-columns';
					break;
				case 3:
					$holderClasses[] = 'mkdf-clients-three-columns';
					break;
				case 4:
					$holderClasses[] = 'mkdf-clients-four-columns';
					break;
				case 5:
					$holderClasses[] = 'mkdf-clients-five-columns';
					break;
				case 6:
					$holderClasses[] = 'mkdf-clients-six-columnss';
					break;
				default:
					$holderClasses[] = 'mkdf-clients-two-columns';
					break;
			}

			if($params['disable_separator'] !== '') {
				$holderClasses[] = 'separator-disabled';
			}
		}

		return $holderClasses;
	}

	private function getHolderInnerClasses($params){
		$holderClasses = '';

		if($params['type'] == 'carousel') {
			$holderClasses .= 'mkdf-owl-slider';
		}

		return $holderClasses;
	}
	
	/**
	 * Return all configuration data for slider
	 *
	 * @param $params
	 * @return array
	 */
	private function getSliderData($params) {
		$slider_data = array();
		
		$slider_data['data-number-of-items']        = !empty($params['number_of_visible_items']) ? $params['number_of_visible_items'] : '4';
		$slider_data['data-enable-loop']            = !empty($params['slider_loop']) ? $params['slider_loop'] : '';
		$slider_data['data-enable-autoplay']        = !empty($params['slider_autoplay']) ? $params['slider_autoplay'] : '';
		$slider_data['data-slider-speed']           = !empty($params['slider_speed']) ? $params['slider_speed'] : '5000';
		$slider_data['data-slider-speed-animation'] = !empty($params['slider_speed_animation']) ? $params['slider_speed_animation'] : '600';
		$slider_data['data-enable-navigation']      = !empty($params['slider_navigation']) ? $params['slider_navigation'] : '';
		$slider_data['data-enable-pagination']      = !empty($params['slider_pagination']) ? $params['slider_pagination'] : '';
		
		return $slider_data;
	}
}